@@ -2,6 +2,7 @@
 from dataclasses import dataclass
 
 from aiohttp.client import ClientTimeout
+from aiohttp.hdrs import IF_NONE_MATCH
 
 from .base import HaVersionBase
 from .consts import (
@@ -20,9 +21,8 @@ from .consts import (
     DEFAULT_HEADERS,
     DEFAULT_IMAGE,
     LOGGER,
-    HaVersionSource,
 )
-from .exceptions import HaVersionInputException
+from .exceptions import HaVersionInputException, HaVersionNotModifiedException
 
 URL = "https://version.home-assistant.io/{channel}.json"
 
@@ -31,8 +31,6 @@ URL = "https://version.home-assistant.io/{channel}.json"
 class HaVersionSupervisor(HaVersionBase):
     """Handle versions for the Supervisor source."""
 
-    source = HaVersionSource.SUPERVISOR
-
     def validate_input(self) -> None:
         """Raise HaVersionInputException if expected input are missing."""
         if self.session is None:
@@ -42,11 +40,20 @@ class HaVersionSupervisor(HaVersionBase):
 
     async def fetch(self, **kwargs):
         """Logic to fetch new version data."""
+        headers = DEFAULT_HEADERS
+        if (etag := kwargs.get("etag")) is not None:
+            headers[IF_NONE_MATCH] = etag
+
         request = await self.session.get(
             url=URL.format(channel=self.channel),
-            headers=DEFAULT_HEADERS,
+            headers=headers,
             timeout=ClientTimeout(total=self.timeout),
         )
+        self._etag = request.headers.get("Etag")
+
+        if request.status == 304:
+            raise HaVersionNotModifiedException
+
         self._data = await request.json()
 
     def parse(self):
